from pygame import draw, gfxdraw
from pygame.rect import Rect as pRect

class Rect:

    def __init__(self, x, y, width, height):
        self.x = x
        self.y = y
        self.height = height
        self.width = width
        self.update()

    def update(self):
        self.min_x = self.x
        self.min_y = self.y
        self.max_x = self.x + self.width
        self.max_y = self.y + self.height

        self.min = (self.min_x, self.min_y)
        self.max = (self.max_x, self.max_y)

        self.halfwidth = self.width / 2
        self.halfheight = self.height / 2

        self.cx = self.x + self.width / 2
        self.cy = self.y + self.height / 2

        self.vertices = [
            (self.x, self.y),
            (self.x + self.width, self.y),
            (self.x + self.width, self.y + self.height),
            (self.x, self.y + self.height)
        ]
        self.segments = [
            (self.vertices[0], self.vertices[1]),
            (self.vertices[1], self.vertices[2]),
            (self.vertices[2], self.vertices[3]),
            (self.vertices[3], self.vertices[0]),
        ]

    def get_center(self):
        return (self.cx, self.cy)

    def get_center_px(self):
        return (int(self.cx), int(self.cy))

    def contains(self, x, y):
        return (x >= self.min_x and x <= self.max_x
                and y >= self.min_y and y <= self.max_y)

    def draw(self, surface, colour, width):
        #gfxdraw.pixel(surface, *self.get_center_px(), colour)
        draw.rect(surface, colour,
                  pRect(self.x, self.y, self.width, self.height),
                  width)
